@@ -7,9 +7,11 @@ import qualified GI.GObject.Config as GObject
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "Dbusmenu"
         version = "0.4"
+        pkgName = "gi-dbusmenu"
+        pkgVersion = "0.4.10"
         overridesFile = Just "Dbusmenu.overrides"
         verbose = False
         outputDir = Nothing
